@@ -49,7 +49,7 @@ class QT_SIGNALSLOTEDITOR_EXPORT SignalSlotEditorTool: public QDesignerFormWindo
 {
     Q_OBJECT
 public:
-    explicit SignalSlotEditorTool(QDesignerFormWindowInterface *formWindow, QObject *parent = 0);
+    explicit SignalSlotEditorTool(QDesignerFormWindowInterface *formWindow, QObject *parent = nullptr);
     ~SignalSlotEditorTool() override;
 
     QDesignerFormEditorInterface *core() const override;
