@@ -72,13 +72,13 @@ private:
 QTabWidgetEventFilter::QTabWidgetEventFilter(QTabWidget *parent) :
     QObject(parent),
     m_tabWidget(parent),
-    m_dropIndicator(0),
-    m_dragPage(0),
+    m_dropIndicator(nullptr),
+    m_dragPage(nullptr),
     m_mousePressed(false),
     m_actionDeletePage(new QAction(tr("Delete"),  this)),
     m_actionInsertPage(new QAction(tr("Before Current Page"), this)),
     m_actionInsertPageAfter(new QAction(tr("After Current Page"), this)),
-    m_pagePromotionTaskMenu(new qdesigner_internal::PromotionTaskMenu(0, qdesigner_internal::PromotionTaskMenu::ModeSingleWidget, this))
+    m_pagePromotionTaskMenu(new qdesigner_internal::PromotionTaskMenu(nullptr, qdesigner_internal::PromotionTaskMenu::ModeSingleWidget, this))
 {
     tabBar()->setAcceptDrops(true);
     tabBar()->installEventFilter(this);
@@ -103,14 +103,14 @@ QTabWidgetEventFilter *QTabWidgetEventFilter::eventFilterOf(const QTabWidget *ta
             if (QTabWidgetEventFilter *ef = qobject_cast<QTabWidgetEventFilter*>(o))
                 return ef;
     }
-    return 0;
+    return nullptr;
 }
 
 QMenu *QTabWidgetEventFilter::addTabWidgetContextMenuActions(const QTabWidget *tabWidget, QMenu *popup)
 {
     QTabWidgetEventFilter *filter = eventFilterOf(tabWidget);
     if (!filter)
-        return 0;
+        return nullptr;
     return filter->addContextMenuActions(popup);
 }
 
@@ -118,9 +118,9 @@ QTabBar *QTabWidgetEventFilter::tabBar() const
 {
     // QTabWidget::tabBar() accessor is protected, grmbl...
     if (!m_cachedTabBar) {
-        const QList<QTabBar *> tabBars = m_tabWidget->findChildren<QTabBar *>();
+        const auto tabBars = m_tabWidget->findChildren<QTabBar *>();
         Q_ASSERT(tabBars.size() == 1);
-        m_cachedTabBar = tabBars.front();
+        m_cachedTabBar = tabBars.constFirst();
     }
     return m_cachedTabBar;
 
@@ -217,7 +217,7 @@ bool QTabWidgetEventFilter::eventFilter(QObject *o, QEvent *e)
 
             m_tabWidget->removeTab(m_dragIndex);
 
-            const Qt::DropActions dropAction = drg->start(Qt::MoveAction);
+            const Qt::DropActions dropAction = drg->exec(Qt::MoveAction);
 
             if (dropAction == Qt::IgnoreAction) {
                 // abort
@@ -352,7 +352,7 @@ int QTabWidgetEventFilter::pageFromPosition(const QPoint &pos, QRect &rect) cons
 
 QMenu *QTabWidgetEventFilter::addContextMenuActions(QMenu *popup)
 {
-    QMenu *pageMenu = 0;
+    QMenu *pageMenu = nullptr;
     const int count = m_tabWidget->count();
     m_actionDeletePage->setEnabled(count);
     if (count) {
@@ -404,9 +404,9 @@ QTabWidgetPropertySheet::QTabWidgetPropertySheet(QTabWidget *object, QObject *pa
 
 QTabWidgetPropertySheet::TabWidgetProperty QTabWidgetPropertySheet::tabWidgetPropertyFromName(const QString &name)
 {
-    typedef QHash<QString, TabWidgetProperty> TabWidgetPropertyHash;
+    using TabWidgetPropertyHash = QHash<QString, TabWidgetProperty>;
     static TabWidgetPropertyHash tabWidgetPropertyHash;
-    if (tabWidgetPropertyHash.empty()) {
+    if (tabWidgetPropertyHash.isEmpty()) {
         tabWidgetPropertyHash.insert(QLatin1String(currentTabTextKey),      PropertyCurrentTabText);
         tabWidgetPropertyHash.insert(QLatin1String(currentTabNameKey),      PropertyCurrentTabName);
         tabWidgetPropertyHash.insert(QLatin1String(currentTabIconKey),      PropertyCurrentTabIcon);
