@@ -198,7 +198,7 @@ namespace qdesigner_internal
     QString DesignerMetaFlags::toString(int value, SerializationMode sm) const
     {
         const QStringList flagIds = flags(value);
-        if (flagIds.empty())
+        if (flagIds.isEmpty())
             return QString();
 
         const QChar delimiter = QLatin1Char('|');
@@ -270,9 +270,7 @@ namespace qdesigner_internal
     {
     }
 
-    PropertySheetPixmapValue::PropertySheetPixmapValue()
-    {
-    }
+    PropertySheetPixmapValue::PropertySheetPixmapValue() = default;
 
     PropertySheetPixmapValue::PixmapSource PropertySheetPixmapValue::getPixmapSource(QDesignerFormEditorInterface *core, const QString & path)
     {
@@ -693,11 +691,11 @@ namespace qdesigner_internal
 
     QDESIGNER_SHARED_EXPORT QAction *preferredEditAction(QDesignerFormEditorInterface *core, QWidget *managedWidget)
     {
-        QAction *action = 0;
+        QAction *action = nullptr;
         if (const QDesignerTaskMenuExtension *taskMenu = qt_extension<QDesignerTaskMenuExtension*>(core->extensionManager(), managedWidget)) {
             action = taskMenu->preferredEditAction();
             if (!action) {
-                const QList<QAction *> actions = taskMenu->taskActions();
+                const auto actions = taskMenu->taskActions();
                 if (!actions.isEmpty())
                     action = actions.first();
             }
@@ -707,7 +705,7 @@ namespace qdesigner_internal
                         core->extensionManager()->extension(managedWidget, QStringLiteral("QDesignerInternalTaskMenuExtension")))) {
                 action = taskMenu->preferredEditAction();
                 if (!action) {
-                    const QList<QAction *> actions = taskMenu->taskActions();
+                    const auto actions = taskMenu->taskActions();
                     if (!actions.isEmpty())
                         action = actions.first();
                 }
@@ -716,13 +714,25 @@ namespace qdesigner_internal
         return action;
     }
 
-    QDESIGNER_SHARED_EXPORT bool runUIC(const QString &fileName, QByteArray& ba, QString &errorMessage)
+    QDESIGNER_SHARED_EXPORT bool runUIC(const QString &fileName, UicLanguage language,
+                                        QByteArray& ba, QString &errorMessage)
     {
-        const QString binary = QLibraryInfo::location(QLibraryInfo::BinariesPath) + QStringLiteral("/uic");
         QProcess uic;
-        uic.start(binary, QStringList(fileName));
+        QStringList arguments;
+        QString binary = QLibraryInfo::location(QLibraryInfo::BinariesPath) + QStringLiteral("/uic");
+        switch (language) {
+        case UicLanguage::Cpp:
+            break;
+        case UicLanguage::Python:
+            arguments << QLatin1String("-g") << QLatin1String("python");
+            break;
+        }
+        arguments << fileName;
+
+        uic.start(binary, arguments);
         if (!uic.waitForStarted()) {
-            errorMessage = QApplication::translate("Designer", "Unable to launch %1.").arg(binary);
+            errorMessage = QApplication::translate("Designer", "Unable to launch %1: %2").
+                           arg(QDir::toNativeSeparators(binary), uic.errorString());
             return false;
         }
         if (!uic.waitForFinished()) {
